@@ -3,6 +3,11 @@ from marshmallow import fields, ValidationError
 
 
 class DataType(Enum):
+    """
+    Enum that represents a datatype. Includes
+    various convenience functions
+    """
+
     VOID = 0
     BOOL = 1
     UINT8 = 2
@@ -15,7 +20,7 @@ class DataType(Enum):
     INT64 = 9
     FLOAT = 10
     DOUBLE = 11
-    STR=12
+    STR = 12
 
     @property
     def nickname(self):
@@ -33,6 +38,12 @@ class DataType(Enum):
     def is_void(self):
         return DataType.VOID == self
 
+    def from_string(self, str_value):
+        if self == DataType.VOID:
+            return None
+        else:
+            return py_type_map[self](str_value)
+
 
 c_type_map = {
     DataType.VOID: "void",
@@ -45,7 +56,21 @@ c_type_map = {
     DataType.UINT32: "uint32_t",
     DataType.FLOAT: "float",
     DataType.DOUBLE: "double",
-    DataType.STR: "str"
+    DataType.STR: "str",
+}
+
+py_type_map = {
+    DataType.VOID: None,
+    DataType.BOOL: bool,
+    DataType.INT8: int,
+    DataType.UINT8: int,
+    DataType.INT16: int,
+    DataType.UINT16: int,
+    DataType.INT32: int,
+    DataType.UINT32: int,
+    DataType.FLOAT: float,
+    DataType.DOUBLE: float,
+    DataType.STR: str,
 }
 
 datatype_sizes = {
@@ -59,7 +84,7 @@ datatype_sizes = {
     DataType.UINT32: 4,
     DataType.FLOAT: 4,
     DataType.DOUBLE: 8,
-    DataType.STR: -1
+    DataType.STR: -1,
 }
 
 
@@ -74,7 +99,7 @@ datatype_names = {
     "uint32": DataType.UINT32,
     "float": DataType.FLOAT,
     "double": DataType.DOUBLE,
-    "string": DataType.STR
+    "string": DataType.STR,
 }
 
 
