@@ -1,3 +1,4 @@
+import os
 from copy import copy
 
 
@@ -10,9 +11,9 @@ def avlos_endpoints(input):
     def traverse_endpoint_list(ep_list, ep_out_list):
         for ep in ep_list:
             if (
-                hasattr(ep, "c_getter")
-                or hasattr(ep, "c_setter")
-                or hasattr(ep, "c_caller")
+                hasattr(ep, "getter_name")
+                or hasattr(ep, "setter_name")
+                or hasattr(ep, "caller_name")
             ):
                 ep_out_list.append(ep)
             elif hasattr(ep, "remote_attributes"):
@@ -43,3 +44,10 @@ def as_include(input):
     elif input.startswith("<") and input.endswith(">"):
         return input
     return "<" + input + ">"
+
+
+def file_from_path(input):
+    """
+    Get the file string from a path string
+    """
+    return os.path.basename(input)
