@@ -10,6 +10,10 @@ class CommNode:
     def parent(self):
         return self._parent
 
+    @cached_property
+    def root(self):
+        return self._parent.root
+
     @cached_property
     def channel(self):
         try:
